<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * Comments module class file.
 */
class CommentsModule extends CWebModule
{
    /**
     * @var string salt which is used for every hash operation in this module
     */
    public $hashSalt = 'h1ads29ds1a91hgj29jl451';

    public $notificationsEmail = 'comments@example.com';

    private $_assetsUrl;

    /**
     * page contained UserLoginWidget
     *
     * @return mixed
     */
    public function getLoginUrl()
    {
        return is_array(Yii::app()->getModule('user')->loginUrl) ? Yii::app()->getModule('user')->loginUrl[0] : Yii::app()->getModule('user')->loginUrl;
    }

    /**
     * @var int the number of seconds in which the cached value will expire. 0 means never expire.
     */
    public $cacheTime = 60;

    /**
     * Import dependent classes
     *
     * @return void
     */
    public function init()
    {
        // import the module-level models and components
        $this->setImport(
            array(
                'comments.models.*',
                'comments.widgets.*',
            )
        );
    }


    /**
     * Check if current user have delete permission on comment
     *
     * @param Comment $comment comment for operation
     *
     * @return bool
     */
    public static function canDelete(Comment $comment)
    {
        return
            ($comment->user_id != null && $comment->user_id == Yii::app()->user->id) ||
            $comment->moderator_email == Yii::app()->user->email ||
            Yii::app()->user->checkAccess('manageComments');
    }

    /**
     * Check if current user have approve permission on comment
     *
     * @param Comment $comment comment model
     *
     * @return bool
     */
    public static function canApprove($comment)
    {
        return $comment->moderator_email == Yii::app()->user->email || Yii::app()->user->checkAccess('manageComments');
    }

    /**
     * Check if exists comments with such moderator email
     *
     * @param string $email email
     *
     * @return bool
     */
    public static function isEmailModerator($email)
    {
        return !empty($email) ? Comment::model()->countByAttributes(array('moderator_email' => $email)) > 0 : false;
    }

    /**
     * Publish module assets and return url
     *
     * @return string
     */
    public function getAssetsUrl()
    {
        if (!$this->_assetsUrl) {
            $this->_assetsUrl = Yii::app()->assetManager->publish(Yii::getPathOfAlias('comments.assets'), true);
        }
        return $this->_assetsUrl;
    }

    /**
     * Translates a message to the specified language.
     *
     * @param string $str    message
     * @param array  $params params
     * @param string $dic    dictionary
     *
     * @return string
     */
    public static function t($str = '', $params = array(), $dic = 'core')
    {
        return Yii::t("CommentsModule." . $dic, $str, $params);
    }
}
