<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * This class represents friendship between two Users
 *
 * @property int $user1_id
 * @property int $user2_id
 * @property int $status
 * @property User $user1
 * @property User $user2
 */
class Friendship extends CActiveRecord
{

    const STATUS_CANCELED = -1;
    const STATUS_NOT_APPROVED = 0;
    const STATUS_APPROVED = 1;

    /**
     * Returns the static model of the specified AR class.
     *
     * @param string $className active record class name
     *
     * @return array|CActiveRecord
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * Returns the name of the associated database table.
     * By default this method returns the class name as the table name.
     * You may override this method if the table is not named after this convention.
     *
     * @return string the table name
     */
    public function tableName()
    {
        return '{{friendship}}';
    }

    public function rules()
    {
        return array(
            array('user1_id, user2_id, status', 'required'),
            array('user1_id, user2_id, status', 'numerical', 'integerOnly' => true)
        );
    }

    public function relations()
    {
        return array(
            'user1' => array(CActiveRecord::BELONGS_TO, 'User', 'user1_id'),
            'user2' => array(CActiveRecord::BELONGS_TO, 'User', 'user2_id'),
        );
    }


    /**
     * Returns friend User model.
     *
     * @param int $user_id id of some user in this friendship
     *
     * @return null|User his friend
     */
    public function friend($user_id)
    {
        if ($user_id == $this->user1_id) {
            return $this->user2;
        } elseif ($user_id == $this->user2_id) {
            return $this->user1;
        }
        return null;
    }

    /**
     * Get User model of user with $user_id
     *
     * @param int $user_id id of some user in this friendship
     *
     * @return null|User his model
     */
    public function me($user_id)
    {
        if ($user_id == $this->user1->id) {
            return $this->user1;
        } elseif ($user_id == $this->user2->id) {
            return $this->user2;
        }
        return null;
    }

    /**
     * Check if user with $user_id make friend request or not
     *
     * @param int $user_id id of needed user
     *
     * @return bool
     */
    public function myRequest($user_id)
    {
        if ($user_id == $this->user1->id) {
            return true;
        }

        return false;
    }
    /**
     * If the user was removed after friendship with him was
     * created gportal will destruct such relations to avoid errors
     *
     */

    protected function afterFind()
    {
        parent::afterFind();
        if(!isset($this->user1) || !isset($this->user2)){
            $this->delete();
        }
    }

}
