<?php
/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 */

class PersonalisationModule extends CWebModule
{

    public $cacheTime = 0;

    private $_rule;
    private $_assetsUrl;

    /**
     * Personalisation rule setter
     *
     * @param array $config configuration
     *
     * @return void
     */
    public function setRule($config)
    {
        if (is_string($config)) {
            $config = array('class'=>$config);
        }
        $this->_rule = Yii::createComponent($config);

    }

    /**
     * Personalisation rule getter
     *
     * @return BasicPersonalisationRule
     */
    public function getRule()
    {
        return $this->_rule;
    }


    /**
     * Initializes the module.
     *
     * @return void
     */
    public function init()
    {
        $this->setImport(
            array(
                'personalisation.components.*',
                'site.custom.modules.personalisation.components.*',
                'personalisation.helpers.*',
                'personalisation.models.*',
                'personalisation.widgets.*',
            )
        );
    }

    /**
     * Publish module assets and return url
     *
     * @return string
     */
    public function getAssetsUrl()
    {
        if (!$this->_assetsUrl) {
            $this->_assetsUrl = Yii::app()->assetManager->publish(Yii::getPathOfAlias('personalisation.assets'), true);
        }
        return $this->_assetsUrl;
    }

    /**
     * Translates a message to the specified language.
     *
     * @param string $str    message
     * @param array  $params params
     * @param string $dic    dictionary
     *
     * @return string
     */
    public static function t($str = '', $params = array(), $dic = 'core')
    {
        return Yii::t("PersonalisationModule." . $dic, $str, $params);
    }

}
