<?php

/**
 * Gentics Portal.Node PHP
 * Author & Copyright (c) by Gentics Software GmbH
 * sales@gentics.com
 * http://www.gentics.com
 * Licenses can be found in the LICENSE.txt file in the root-folder of this installation
 * You must not use this software without a valid license agreement.
 *
 * This is the model class for table "{{user_personalization_attributes}}".
 * Represents assigning personalisation attribute to user
 *
 * The followings are the available columns in table '{{user_personalization_attributes}}':
 * @property integer $user_id
 * @property integer $personalisation_attribute_id
 */
class UserPersonalisationAttribute extends CActiveRecord
{
    /**
     * Returns the static model of the specified AR class.
     *
     * @param string $className active record class name.
     *
     * @return UserPersonalisationAttribute the static model class
     */
    public static function model($className = __CLASS__)
    {
        return parent::model($className);
    }

    /**
     * Returns the associated database table name
     *
     * @return string
     */
    public function tableName()
    {
        return '{{user_personalisation_attributes}}';
    }

    /**
     * Returns validation rules for model attributes.
     *
     * @return array
     */
    public function rules()
    {
        // NOTE: you should only define rules for those attributes that
        // will receive user inputs.
        return array(
            array('user_id, personalisation_attribute_id', 'required'),
            array('user_id, personalisation_attribute_id', 'numerical', 'integerOnly' => true),
            // The following rule is used by search().
            // Please remove those attributes that should not be searched.
            array('user_id, personalisation_attribute_id', 'safe', 'on' => 'search'),
        );
    }

    /**
     * Returns relational rules.
     *
     * @return array
     */
    public function relations()
    {
        // NOTE: you may need to adjust the relation name and the related
        // class name for the relations automatically generated below.
        return array(
            'user' => array(self::BELONGS_TO, 'User', 'user_id'),
            'personalisationAttribute' => array(self::BELONGS_TO, 'PersonalisationAttribute', array('personalisation_attribute_id' => 'id'))
        );
    }

    /**
     * Returns customized attribute labels (name=>label)
     *
     * @return array
     */
    public function attributeLabels()
    {
        return array(
            'user_id' => 'User',
            'personalisation_attribute_id' => 'Personalisation Attribute',
        );
    }

    /**
     * Retrieves a list of models based on the current search/filter conditions.
     *
     * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
     */
    public function search()
    {
        // Warning: Please modify the following code to remove attributes that
        // should not be searched.

        $criteria = new CDbCriteria;

        $criteria->compare('user_id', $this->user_id);
        $criteria->compare('personalisation_attribute_id', $this->personalisation_attribute_id);

        return new CActiveDataProvider(
            $this,
            array(
                'criteria' => $criteria,
            )
        );
    }
}