<?php
/**
 *
 */
class SUserIdentity extends CUserIdentity
{
    const ERROR_NOT_AUTHENTICATED = 3;

    /**
     * @var EAuthServiceBase the authorization service instance.
     */
    protected $service;

    /**
     * @var string the unique identifier for the identity.
     */
    protected $id;

    public $user = null;

    public $session = null;

    public $account = null;

    public $email;

    /**
     * Constructor.
     * @param EAuthServiceBase $service the authorization service instance.
     */
    public function __construct($service)
    {
        $this->service = $service;
    }

    /**
     * Authenticates a user based on {@link service}.
     * This method is required by {@link IUserIdentity}.
     * @return boolean whether authentication succeeds.
     */
    public function authenticate()
    {
        if ($this->service->isAuthenticated) {
            $id = $this->service->id;
            $service = $this->service->serviceName;

            $this->account = Account::model()->findByAttributes(array('service' => $service, 'service_id' => $id));
            if (!$this->account) {
                $this->account = Account::create($this->service);
                if ($this->account) {
                    if (User::create($this->account, $this->service)) {
                        $this->onNewUser($this->account);
                    }
                }
            }

            if ($this->account->user->status == 1) {
                $this->id = $this->account->user_id;
                $this->username = $this->account->user->username;
                $this->email = $this->account->user->email;

                /*echo __FILE__.'<br/>';*/
                //if new data from service
                $data = (object)array_merge((array)$this->account->data, $this->service->getAttributes());
                $this->account->data = $data;
                $this->account->save();

                $profile = Profile::model()->findByAttributes(array('user_id'=>$this->account->user->id));

                if (!empty($data->firstname)) {
                    $profile->firstname = $data->firstname;
                    $this->account->user->profile->firstname = $data->firstname;
                }
                if (!empty($data->lastname)) {
                    $profile->lastname = $data->lastname;
                    $this->account->user->profile->lastname = $data->lastname;
                }
                if (!empty($data->gender)) {
                    $profile->gender = $data->gender;
                    $this->account->user->profile->gender = $data->gender;
                }

                if (!$profile->save(false)) {
                    throw new Exception(print_r($profile->getErrors(), true));
                }

                Yii::app()->getModule('personalisation');
                $this->setPersistentStates(array(
                    'email' => $this->email,
                    'firstname' => $this->account->user->profile->firstname,
                    'lastname' => $this->account->user->profile->lastname,
                    'gender' => $this->account->user->profile->gender,
                    'personalisation' => PersonalisationAttribute::flatListForUser($this->account->user->id)
                ));

                $this->errorCode = self::ERROR_NONE;
            } else {
                $this->errorCode = self::ERROR_NOT_AUTHENTICATED;
            }
        }
        else {
            $this->errorCode = self::ERROR_NOT_AUTHENTICATED;
        }
        return !$this->errorCode;
    }

    /**
     * Returns the unique identifier for the identity.
     * This method is required by {@link IUserIdentity}.
     * @return string the unique identifier for the identity.
     */
    public function getId()
    {
        return $this->id;
    }

    public function getErrorDescription()
    {
        $error = '';
        switch ($this->errorCode)
        {
            case self::ERROR_NOT_AUTHENTICATED:
                $error = 'Not authenticated';
                break;
            default:
                break;
        }

        return $error;
    }

    public function onNewUser(Account $account)
    {
        $message = "User '{$account->user->username}' from TPA '{$account->service}' created";
        $notification = new Notification('TPA', $message);
        Yii::app()->notificationManager->notifyAbout($notification);
    }
}
